
%% FUNCTIONS
%% mat_creator: generates a structure of (n_clusters_input x n_clusters_output) matrices. 
% If second argument=1, the structure will be used for parallel connectivity

%% layer_creator: it generates a group of clusters (2nd argument) with a specified numerosity (3rd),
% a structure of parameters for the matrix of connections within each clusters (4th), 
% a structure of parameters for the matrix of connections among all clusters (5th)
% general decay for all units (5th), level of noise in action potential of all units (6th)
% and basal activation of the cluster as a whole (7th);

%% layer_step: step function updating the activity of all units in all clusters in a layer.
% it processes up to 3 inputs for each layer: 3rd and 4th arguments (activity and relative connections),
% 5th and 6th, 7th and 8th (those unused can be left blank)

%% START
clear all
close all

tic

%% SEED to control pseudo-random variables
rng(201)
%%

SECS=1.0;                       
dt=0.5;                             % integration
T= SECS*1000/dt;                    % total time simulated

n_clust_layers=4;                   %number of clusters in a layer
n_clust_inp=4;                      %number of clusters for the input

cl_dim =100;                        %number of units per cluster in a layer
dim_inp=200;                        %number of units in input cluster


%% input
input.activity{1}= zeros(T,dim_inp);
input.activity{2}= zeros(T,dim_inp);
input.activity{3}= zeros(T,dim_inp);
input.activity{4}= zeros(T,dim_inp);
input_creator;

perc_conninp=0.1;                   %0-1 scale: 1=fully intercconnected (independently of value)
perc_GABAinp=0.0;                   %0-1 scale
str_coninp=[1.00 1.50];             %[a b]: the strength of the connections in the cluster is a<x<b

mat_inp_l1=mat_creator(n_clust_inp, 1, dim_inp, cl_dim, perc_conninp, perc_GABAinp, str_coninp);

%% Generic structure of clusters
decay=3;                            %decay per layer
noise=0;                            %noise per layer: if noise=1 -> bl=bl+-10
c_baseline=0.00;                    %0-1 scale: basal activation of the cluster, in terms of percentage of spikes per step

cluster_mat.perc_conn=0.25;         %0-1 scale: 1=fully intercconnected (independently of value)
cluster_mat.perc_GABA=0.5;          %0-1 scale
cluster_mat.str_conn =[0.9 1.0];    %0-1 scale: strength of connections in the cluster

layer_mat.perc_conn =0.15;          %0-1 scale: 1=fully intercconnected (independently of value)
layer_mat.perc_GABA =1.00;          %0-1 scale
layer_mat.str_conn  =[2.00 2.00];   %[a b]: the strength of the connections in the cluster is a<x<b.

layer1=layer_creator(T, n_clust_layers, cl_dim, cluster_mat, layer_mat, decay, noise, c_baseline);

for t=2:T
 
    layer1=layer_step(t, dt, layer1, input, mat_inp_l1, 0, 0, 0, 0);
    
end

plotting_imagesc;

toc